@@ -1,12 +1,12 @@
 package File::Sticker::Reader::Mp3;
-$File::Sticker::Reader::Mp3::VERSION = '3.0204';
+$File::Sticker::Reader::Mp3::VERSION = '3.03';
 =head1 NAME
 
 File::Sticker::Reader::Mp3 - read and standardize meta-data from MP3 file
 
 =head1 VERSION
 
-version 3.0204
+version 3.03
 
 =head1 SYNOPSIS
 
@@ -89,6 +89,8 @@ sub known_fields {
         title=>'TEXT',
         creator=>'TEXT',
         author=>'TEXT',
+        composer=>'TEXT',
+        performer=>'TEXT',
         description=>'TEXT',
         song=>'TEXT',
         genre=>'TEXT',
@@ -151,9 +153,18 @@ sub read_meta {
         {
             $meta{'track'} = $mp3->track();
         }
+        elsif ($field eq 'composer')
+        {
+            $meta{'composer'} = $mp3->composer();
+        }
+        elsif ($field eq 'performer')
+        {
+            $meta{'performer'} = $mp3->performer();
+        }
         elsif ($field eq 'author')
         {
             # author (as distinct from artist) use the 'composer' field
+            # This is used for podfic, whereas composer is used for music.
             $meta{'author'} = $mp3->composer();
         }
         elsif ($field eq 'url')
