@@ -1,12 +1,12 @@
 package File::Sticker::Writer::Mp3;
-$File::Sticker::Writer::Mp3::VERSION = '3.0204';
+$File::Sticker::Writer::Mp3::VERSION = '3.03';
 =head1 NAME
 
 File::Sticker::Writer::Mp3 - write and standardize meta-data from MP3 file
 
 =head1 VERSION
 
-version 3.0204
+version 3.03
 
 =head1 SYNOPSIS
 
@@ -104,9 +104,11 @@ sub known_fields {
 
     return {
         title=>'TEXT',
-        description=>'TEXT',
         creator=>'TEXT',
         author=>'TEXT',
+        composer=>'TEXT',
+        performer=>'TEXT',
+        description=>'TEXT',
         genre=>'TEXT',
         song=>'TEXT',
         url=>'TEXT',
@@ -184,9 +186,18 @@ sub replace_one_field {
     {
         $mp3->track_set($value);
     }
+    elsif ($field eq 'performer')
+    {
+        $mp3->select_id3v2_frame_by_descr('TPE1', $value);
+    }
+    elsif ($field eq 'composer')
+    {
+        $mp3->select_id3v2_frame_by_descr('TCOM', $value);
+    }
     elsif ($field eq 'author')
     {
-        # use the 'composer' field
+        # Use the 'composer' field
+        # This is used for podfic, whereas composer is used for music.
         $mp3->select_id3v2_frame_by_descr('TCOM', $value);
     }
     elsif ($field eq 'url')
@@ -242,6 +253,14 @@ sub delete_field_from_file {
     {
         $mp3->artist_set('');
     }
+    elsif ($field eq 'performer')
+    {
+        $mp3->select_id3v2_frame_by_descr('TPE1', undef);
+    }
+    elsif ($field eq 'composer')
+    {
+        $mp3->select_id3v2_frame_by_descr('TCOM', undef);
+    }
     elsif ($field eq 'author')
     {
         # use the 'composer' field
